/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED BY BPFTOOL! */
#ifndef __SOCK_ADDR_KERN_SKEL_H__
#define __SOCK_ADDR_KERN_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

#define BPF_SKEL_SUPPORTS_MAP_AUTO_ATTACH 1

struct sock_addr_kern {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_program *init_sock;
		struct bpf_program *close_sock;
		struct bpf_program *kernel_connect;
		struct bpf_program *kernel_bind;
		struct bpf_program *kernel_listen;
		struct bpf_program *kernel_sendmsg;
		struct bpf_program *sock_sendmsg;
		struct bpf_program *kernel_getsockname;
		struct bpf_program *kernel_getpeername;
	} progs;
	struct {
		struct bpf_link *init_sock;
		struct bpf_link *close_sock;
		struct bpf_link *kernel_connect;
		struct bpf_link *kernel_bind;
		struct bpf_link *kernel_listen;
		struct bpf_link *kernel_sendmsg;
		struct bpf_link *sock_sendmsg;
		struct bpf_link *kernel_getsockname;
		struct bpf_link *kernel_getpeername;
	} links;

#ifdef __cplusplus
	static inline struct sock_addr_kern *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct sock_addr_kern *open_and_load();
	static inline int load(struct sock_addr_kern *skel);
	static inline int attach(struct sock_addr_kern *skel);
	static inline void detach(struct sock_addr_kern *skel);
	static inline void destroy(struct sock_addr_kern *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
sock_addr_kern__destroy(struct sock_addr_kern *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
sock_addr_kern__create_skeleton(struct sock_addr_kern *obj);

static inline struct sock_addr_kern *
sock_addr_kern__open_opts(const struct bpf_object_open_opts *opts)
{
	struct sock_addr_kern *obj;
	int err;

	obj = (struct sock_addr_kern *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = sock_addr_kern__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	sock_addr_kern__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct sock_addr_kern *
sock_addr_kern__open(void)
{
	return sock_addr_kern__open_opts(NULL);
}

static inline int
sock_addr_kern__load(struct sock_addr_kern *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct sock_addr_kern *
sock_addr_kern__open_and_load(void)
{
	struct sock_addr_kern *obj;
	int err;

	obj = sock_addr_kern__open();
	if (!obj)
		return NULL;
	err = sock_addr_kern__load(obj);
	if (err) {
		sock_addr_kern__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
sock_addr_kern__attach(struct sock_addr_kern *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
sock_addr_kern__detach(struct sock_addr_kern *obj)
{
	bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *sock_addr_kern__elf_bytes(size_t *sz);

static inline int
sock_addr_kern__create_skeleton(struct sock_addr_kern *obj)
{
	struct bpf_object_skeleton *s;
	struct bpf_map_skeleton *map __attribute__((unused));
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "sock_addr_kern";
	s->obj = &obj->obj;

	/* programs */
	s->prog_cnt = 9;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "init_sock";
	s->progs[0].prog = &obj->progs.init_sock;
	s->progs[0].link = &obj->links.init_sock;

	s->progs[1].name = "close_sock";
	s->progs[1].prog = &obj->progs.close_sock;
	s->progs[1].link = &obj->links.close_sock;

	s->progs[2].name = "kernel_connect";
	s->progs[2].prog = &obj->progs.kernel_connect;
	s->progs[2].link = &obj->links.kernel_connect;

	s->progs[3].name = "kernel_bind";
	s->progs[3].prog = &obj->progs.kernel_bind;
	s->progs[3].link = &obj->links.kernel_bind;

	s->progs[4].name = "kernel_listen";
	s->progs[4].prog = &obj->progs.kernel_listen;
	s->progs[4].link = &obj->links.kernel_listen;

	s->progs[5].name = "kernel_sendmsg";
	s->progs[5].prog = &obj->progs.kernel_sendmsg;
	s->progs[5].link = &obj->links.kernel_sendmsg;

	s->progs[6].name = "sock_sendmsg";
	s->progs[6].prog = &obj->progs.sock_sendmsg;
	s->progs[6].link = &obj->links.sock_sendmsg;

	s->progs[7].name = "kernel_getsockname";
	s->progs[7].prog = &obj->progs.kernel_getsockname;
	s->progs[7].link = &obj->links.kernel_getsockname;

	s->progs[8].name = "kernel_getpeername";
	s->progs[8].prog = &obj->progs.kernel_getpeername;
	s->progs[8].link = &obj->links.kernel_getpeername;

	s->data = sock_addr_kern__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *sock_addr_kern__elf_bytes(size_t *sz)
{
	static const char data[] __attribute__((__aligned__(8))) = "\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x68\x0e\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x08\0\
\x01\0\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x73\x79\
\x73\x63\x61\x6c\x6c\0\x6c\x69\x63\x65\x6e\x73\x65\0\x73\x6f\x63\x6b\x5f\x61\
\x64\x64\x72\x5f\x6b\x65\x72\x6e\x2e\x63\0\x69\x6e\x69\x74\x5f\x73\x6f\x63\x6b\
\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x69\x6e\x69\x74\x5f\x73\x6f\x63\x6b\
\0\x63\x6c\x6f\x73\x65\x5f\x73\x6f\x63\x6b\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\
\x63\x5f\x63\x6c\x6f\x73\x65\x5f\x73\x6f\x63\x6b\0\x6b\x65\x72\x6e\x65\x6c\x5f\
\x63\x6f\x6e\x6e\x65\x63\x74\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\
\x6c\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x63\x6f\x6e\x6e\x65\x63\x74\0\x6b\x65\
\x72\x6e\x65\x6c\x5f\x62\x69\x6e\x64\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\
\x63\x61\x6c\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x62\x69\x6e\x64\0\x6b\x65\x72\
\x6e\x65\x6c\x5f\x6c\x69\x73\x74\x65\x6e\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\
\x5f\x63\x61\x6c\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x6c\x69\x73\x74\x65\x6e\0\
\x6b\x65\x72\x6e\x65\x6c\x5f\x73\x65\x6e\x64\x6d\x73\x67\0\x62\x70\x66\x5f\x6b\
\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x73\x65\
\x6e\x64\x6d\x73\x67\0\x73\x6f\x63\x6b\x5f\x73\x65\x6e\x64\x6d\x73\x67\0\x62\
\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x73\x6f\x63\x6b\x5f\
\x73\x65\x6e\x64\x6d\x73\x67\0\x6b\x65\x72\x6e\x65\x6c\x5f\x67\x65\x74\x73\x6f\
\x63\x6b\x6e\x61\x6d\x65\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\
\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x67\x65\x74\x73\x6f\x63\x6b\x6e\x61\x6d\
\x65\0\x6b\x65\x72\x6e\x65\x6c\x5f\x67\x65\x74\x70\x65\x65\x72\x6e\x61\x6d\x65\
\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x6b\x65\x72\x6e\
\x65\x6c\x5f\x67\x65\x74\x70\x65\x65\x72\x6e\x61\x6d\x65\0\x5f\x6c\x69\x63\x65\
\x6e\x73\x65\0\x2e\x72\x65\x6c\x73\x79\x73\x63\x61\x6c\x6c\0\x2e\x42\x54\x46\0\
\x2e\x42\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x21\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x32\0\0\0\x12\0\x03\0\0\0\0\0\0\
\0\0\0\x18\0\0\0\0\0\0\0\x3c\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x50\0\0\0\x12\0\x03\0\x18\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x5b\0\0\0\x10\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x70\0\0\0\x12\0\x03\0\x30\0\0\0\0\0\0\0\x10\0\
\0\0\0\0\0\0\x7f\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x9d\0\0\0\x12\
\0\x03\0\x40\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xa9\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\xc4\0\0\0\x12\0\x03\0\x50\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\
\xd2\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xef\0\0\0\x12\0\x03\0\x60\
\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xfe\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x1c\x01\0\0\x12\0\x03\0\x70\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x29\x01\0\0\
\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x45\x01\0\0\x12\0\x03\0\x80\0\0\0\0\
\0\0\0\x10\0\0\0\0\0\0\0\x58\x01\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x7a\x01\0\0\x12\0\x03\0\x90\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x8d\x01\0\0\x10\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xaf\x01\0\0\x11\0\x04\0\0\0\0\0\0\0\0\0\
\x04\0\0\0\0\0\0\0\x85\x10\0\0\xff\xff\xff\xff\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\
\0\0\x85\x10\0\0\xff\xff\xff\xff\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x85\x10\0\
\0\xff\xff\xff\xff\x95\0\0\0\0\0\0\0\x85\x10\0\0\xff\xff\xff\xff\x95\0\0\0\0\0\
\0\0\x85\x10\0\0\xff\xff\xff\xff\x95\0\0\0\0\0\0\0\x85\x10\0\0\xff\xff\xff\xff\
\x95\0\0\0\0\0\0\0\x85\x10\0\0\xff\xff\xff\xff\x95\0\0\0\0\0\0\0\x85\x10\0\0\
\xff\xff\xff\xff\x95\0\0\0\0\0\0\0\x85\x10\0\0\xff\xff\xff\xff\x95\0\0\0\0\0\0\
\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\0\0\0\x04\0\0\0\x18\0\0\0\0\0\0\0\
\x0a\0\0\0\x06\0\0\0\x30\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\x40\0\0\0\0\0\0\0\
\x0a\0\0\0\x0a\0\0\0\x50\0\0\0\0\0\0\0\x0a\0\0\0\x0c\0\0\0\x60\0\0\0\0\0\0\0\
\x0a\0\0\0\x0e\0\0\0\x70\0\0\0\0\0\0\0\x0a\0\0\0\x10\0\0\0\x80\0\0\0\0\0\0\0\
\x0a\0\0\0\x12\0\0\0\x90\0\0\0\0\0\0\0\x0a\0\0\0\x14\0\0\0\x9f\xeb\x01\0\x18\0\
\0\0\0\0\0\0\x3c\x03\0\0\x3c\x03\0\0\x0d\x04\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\
\x01\0\0\0\x02\0\0\x04\x08\0\0\0\x10\0\0\0\x03\0\0\0\0\0\0\0\x13\0\0\0\x03\0\0\
\0\x20\0\0\0\x18\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\0\0\0\0\x01\0\0\x0d\x03\
\0\0\0\x1c\0\0\0\x01\0\0\0\x21\0\0\0\x01\0\0\x0c\x04\0\0\0\0\0\0\0\x01\0\0\x0d\
\x03\0\0\0\0\0\0\0\x01\0\0\0\x2b\0\0\0\x02\0\0\x0c\x06\0\0\0\0\0\0\0\0\0\0\x02\
\0\0\0\0\0\0\0\0\x01\0\0\x0d\x03\0\0\0\x3f\0\0\0\x08\0\0\0\x43\0\0\0\x01\0\0\
\x0c\x09\0\0\0\0\0\0\0\0\0\0\x0d\0\0\0\0\x4e\0\0\0\x02\0\0\x0c\x0b\0\0\0\0\0\0\
\0\0\0\0\x02\x0e\0\0\0\x63\0\0\0\x02\0\0\x04\x84\0\0\0\x6d\0\0\0\x10\0\0\0\0\0\
\0\0\x72\0\0\0\x03\0\0\0\0\x04\0\0\x7a\0\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x01\0\
\0\0\0\0\0\0\x03\0\0\0\0\x0f\0\0\0\x11\0\0\0\x80\0\0\0\x7f\0\0\0\0\0\0\x01\x04\
\0\0\0\x20\0\0\0\0\0\0\0\x01\0\0\x0d\x03\0\0\0\x1c\0\0\0\x0d\0\0\0\x93\0\0\0\
\x01\0\0\x0c\x12\0\0\0\0\0\0\0\x01\0\0\x0d\x03\0\0\0\0\0\0\0\x0d\0\0\0\xa2\0\0\
\0\x02\0\0\x0c\x14\0\0\0\xc0\0\0\0\x01\0\0\x0c\x12\0\0\0\xcc\0\0\0\x02\0\0\x0c\
\x14\0\0\0\xe7\0\0\0\x01\0\0\x0c\x12\0\0\0\0\0\0\0\0\0\0\x0d\x03\0\0\0\xf5\0\0\
\0\x02\0\0\x0c\x19\0\0\0\0\0\0\0\0\0\0\x02\x1c\0\0\0\x12\x01\0\0\x03\0\0\x04\
\x94\0\0\0\x6d\0\0\0\x0e\0\0\0\0\0\0\0\x1f\x01\0\0\x1d\0\0\0\x20\x04\0\0\x23\
\x01\0\0\x03\0\0\0\x80\x04\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x0f\0\0\0\x11\0\0\0\
\x0a\0\0\0\0\0\0\0\x01\0\0\x0d\x03\0\0\0\x1c\0\0\0\x1b\0\0\0\x2a\x01\0\0\x01\0\
\0\x0c\x1e\0\0\0\0\0\0\0\x01\0\0\x0d\x03\0\0\0\0\0\0\0\x1b\0\0\0\x39\x01\0\0\
\x02\0\0\x0c\x20\0\0\0\x57\x01\0\0\x01\0\0\x0c\x1e\0\0\0\x64\x01\0\0\x02\0\0\
\x0c\x20\0\0\0\x80\x01\0\0\x01\0\0\x0c\x12\0\0\0\x93\x01\0\0\x02\0\0\x0c\x14\0\
\0\0\xb5\x01\0\0\x01\0\0\x0c\x12\0\0\0\xc8\x01\0\0\x02\0\0\x0c\x14\0\0\0\0\0\0\
\0\0\0\0\x03\0\0\0\0\x0f\0\0\0\x11\0\0\0\x04\0\0\0\xea\x01\0\0\0\0\0\x0e\x28\0\
\0\0\x01\0\0\0\xf6\x03\0\0\x01\0\0\x0f\x04\0\0\0\x29\0\0\0\0\0\0\0\x04\0\0\0\
\xfe\x03\0\0\x09\0\0\x0f\0\0\0\0\x07\0\0\0\0\0\0\0\0\0\0\0\x0c\0\0\0\0\0\0\0\0\
\0\0\0\x15\0\0\0\0\0\0\0\0\0\0\0\x17\0\0\0\0\0\0\0\0\0\0\0\x1a\0\0\0\0\0\0\0\0\
\0\0\0\x21\0\0\0\0\0\0\0\0\0\0\0\x23\0\0\0\0\0\0\0\0\0\0\0\x25\0\0\0\0\0\0\0\0\
\0\0\0\x27\0\0\0\0\0\0\0\0\0\0\0\0\x69\x6e\x69\x74\x5f\x73\x6f\x63\x6b\x5f\x61\
\x72\x67\x73\0\x61\x66\0\x74\x79\x70\x65\0\x69\x6e\x74\0\x61\x72\x67\x73\0\x69\
\x6e\x69\x74\x5f\x73\x6f\x63\x6b\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x69\
\x6e\x69\x74\x5f\x73\x6f\x63\x6b\0\x63\x74\x78\0\x63\x6c\x6f\x73\x65\x5f\x73\
\x6f\x63\x6b\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x6c\x6f\x73\x65\x5f\
\x73\x6f\x63\x6b\0\x61\x64\x64\x72\x5f\x61\x72\x67\x73\0\x61\x64\x64\x72\0\x61\
\x64\x64\x72\x6c\x65\x6e\0\x63\x68\x61\x72\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\
\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x6b\x65\x72\x6e\x65\x6c\x5f\x63\
\x6f\x6e\x6e\x65\x63\x74\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\
\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x63\x6f\x6e\x6e\x65\x63\x74\0\x6b\x65\x72\
\x6e\x65\x6c\x5f\x62\x69\x6e\x64\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\
\x61\x6c\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x62\x69\x6e\x64\0\x6b\x65\x72\x6e\
\x65\x6c\x5f\x6c\x69\x73\x74\x65\x6e\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\
\x63\x61\x6c\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x6c\x69\x73\x74\x65\x6e\0\x73\
\x65\x6e\x64\x6d\x73\x67\x5f\x61\x72\x67\x73\0\x6d\x73\x67\0\x6d\x73\x67\x6c\
\x65\x6e\0\x6b\x65\x72\x6e\x65\x6c\x5f\x73\x65\x6e\x64\x6d\x73\x67\0\x62\x70\
\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\
\x5f\x73\x65\x6e\x64\x6d\x73\x67\0\x73\x6f\x63\x6b\x5f\x73\x65\x6e\x64\x6d\x73\
\x67\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x73\x6f\x63\
\x6b\x5f\x73\x65\x6e\x64\x6d\x73\x67\0\x6b\x65\x72\x6e\x65\x6c\x5f\x67\x65\x74\
\x73\x6f\x63\x6b\x6e\x61\x6d\x65\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\
\x61\x6c\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x67\x65\x74\x73\x6f\x63\x6b\x6e\
\x61\x6d\x65\0\x6b\x65\x72\x6e\x65\x6c\x5f\x67\x65\x74\x70\x65\x65\x72\x6e\x61\
\x6d\x65\0\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x6b\x65\
\x72\x6e\x65\x6c\x5f\x67\x65\x74\x70\x65\x65\x72\x6e\x61\x6d\x65\0\x5f\x6c\x69\
\x63\x65\x6e\x73\x65\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\
\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x36\x2e\x31\x32\
\x2e\x30\x2d\x35\x35\x2e\x31\x38\x2e\x31\x2e\x65\x6c\x31\x30\x5f\x30\x2f\x6c\
\x69\x6e\x75\x78\x2d\x36\x2e\x31\x32\x2e\x30\x2d\x35\x35\x2e\x31\x38\x2e\x31\
\x2e\x65\x6c\x31\x30\x5f\x30\x2e\x70\x70\x63\x36\x34\x6c\x65\x2f\x74\x6f\x6f\
\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\
\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x73\x6f\x63\x6b\x5f\x61\x64\
\x64\x72\x5f\x6b\x65\x72\x6e\x2e\x63\0\x09\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\
\x5f\x69\x6e\x69\x74\x5f\x73\x6f\x63\x6b\x28\x61\x72\x67\x73\x29\x3b\0\x09\x72\
\x65\x74\x75\x72\x6e\x20\x30\x3b\0\x09\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\
\x63\x6c\x6f\x73\x65\x5f\x73\x6f\x63\x6b\x28\x29\x3b\0\x09\x72\x65\x74\x75\x72\
\x6e\x20\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x6b\x65\
\x72\x6e\x65\x6c\x5f\x63\x6f\x6e\x6e\x65\x63\x74\x28\x61\x72\x67\x73\x29\x3b\0\
\x09\x72\x65\x74\x75\x72\x6e\x20\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\
\x61\x6c\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x62\x69\x6e\x64\x28\x61\x72\x67\
\x73\x29\x3b\0\x09\x72\x65\x74\x75\x72\x6e\x20\x62\x70\x66\x5f\x6b\x66\x75\x6e\
\x63\x5f\x63\x61\x6c\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x6c\x69\x73\x74\x65\
\x6e\x28\x29\x3b\0\x09\x72\x65\x74\x75\x72\x6e\x20\x62\x70\x66\x5f\x6b\x66\x75\
\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x73\x65\x6e\x64\
\x6d\x73\x67\x28\x61\x72\x67\x73\x29\x3b\0\x09\x72\x65\x74\x75\x72\x6e\x20\x62\
\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x73\x6f\x63\x6b\x5f\
\x73\x65\x6e\x64\x6d\x73\x67\x28\x61\x72\x67\x73\x29\x3b\0\x09\x72\x65\x74\x75\
\x72\x6e\x20\x62\x70\x66\x5f\x6b\x66\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x6b\
\x65\x72\x6e\x65\x6c\x5f\x67\x65\x74\x73\x6f\x63\x6b\x6e\x61\x6d\x65\x28\x61\
\x72\x67\x73\x29\x3b\0\x09\x72\x65\x74\x75\x72\x6e\x20\x62\x70\x66\x5f\x6b\x66\
\x75\x6e\x63\x5f\x63\x61\x6c\x6c\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x67\x65\x74\
\x70\x65\x65\x72\x6e\x61\x6d\x65\x28\x61\x72\x67\x73\x29\x3b\0\x6c\x69\x63\x65\
\x6e\x73\x65\0\x2e\x6b\x73\x79\x6d\x73\0\x73\x79\x73\x63\x61\x6c\x6c\0\0\0\0\0\
\0\0\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x54\0\0\0\x54\0\0\0\x2c\x01\0\0\x80\x01\
\0\0\0\0\0\0\x08\0\0\0\x05\x04\0\0\x09\0\0\0\0\0\0\0\x05\0\0\0\x18\0\0\0\x0a\0\
\0\0\x30\0\0\0\x13\0\0\0\x40\0\0\0\x16\0\0\0\x50\0\0\0\x18\0\0\0\x60\0\0\0\x1f\
\0\0\0\x70\0\0\0\x22\0\0\0\x80\0\0\0\x24\0\0\0\x90\0\0\0\x26\0\0\0\x10\0\0\0\
\x05\x04\0\0\x12\0\0\0\0\0\0\0\xf3\x01\0\0\x7d\x02\0\0\x02\x28\0\0\x08\0\0\0\
\xf3\x01\0\0\x99\x02\0\0\x02\x30\0\0\x18\0\0\0\xf3\x01\0\0\xa4\x02\0\0\x02\x48\
\0\0\x20\0\0\0\xf3\x01\0\0\x99\x02\0\0\x02\x50\0\0\x30\0\0\0\xf3\x01\0\0\xbd\
\x02\0\0\x09\x68\0\0\x38\0\0\0\xf3\x01\0\0\xbd\x02\0\0\x02\x68\0\0\x40\0\0\0\
\xf3\x01\0\0\xea\x02\0\0\x09\x80\0\0\x48\0\0\0\xf3\x01\0\0\xea\x02\0\0\x02\x80\
\0\0\x50\0\0\0\xf3\x01\0\0\x14\x03\0\0\x09\x98\0\0\x58\0\0\0\xf3\x01\0\0\x14\
\x03\0\0\x02\x98\0\0\x60\0\0\0\xf3\x01\0\0\x3c\x03\0\0\x09\xb0\0\0\x68\0\0\0\
\xf3\x01\0\0\x3c\x03\0\0\x02\xb0\0\0\x70\0\0\0\xf3\x01\0\0\x69\x03\0\0\x09\xc8\
\0\0\x78\0\0\0\xf3\x01\0\0\x69\x03\0\0\x02\xc8\0\0\x80\0\0\0\xf3\x01\0\0\x94\
\x03\0\0\x09\xe0\0\0\x88\0\0\0\xf3\x01\0\0\x94\x03\0\0\x02\xe0\0\0\x90\0\0\0\
\xf3\x01\0\0\xc5\x03\0\0\x09\xf8\0\0\x98\0\0\0\xf3\x01\0\0\xc5\x03\0\0\x02\xf8\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\x20\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\xd2\x01\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\x10\x02\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x08\0\
\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x11\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x28\x04\0\0\0\0\0\0\xa0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x19\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc8\x04\
\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\xb8\x01\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd0\x04\0\0\0\0\0\0\
\x90\0\0\0\0\0\0\0\x02\0\0\0\x03\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xc4\
\x01\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x60\x05\0\0\0\0\0\0\x61\x07\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc9\x01\0\0\x01\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc8\x0c\0\0\0\0\0\0\xa0\x01\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0";

	*sz = sizeof(data) - 1;
	return (const void *)data;
}

#ifdef __cplusplus
struct sock_addr_kern *sock_addr_kern::open(const struct bpf_object_open_opts *opts) { return sock_addr_kern__open_opts(opts); }
struct sock_addr_kern *sock_addr_kern::open_and_load() { return sock_addr_kern__open_and_load(); }
int sock_addr_kern::load(struct sock_addr_kern *skel) { return sock_addr_kern__load(skel); }
int sock_addr_kern::attach(struct sock_addr_kern *skel) { return sock_addr_kern__attach(skel); }
void sock_addr_kern::detach(struct sock_addr_kern *skel) { sock_addr_kern__detach(skel); }
void sock_addr_kern::destroy(struct sock_addr_kern *skel) { sock_addr_kern__destroy(skel); }
const void *sock_addr_kern::elf_bytes(size_t *sz) { return sock_addr_kern__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
sock_addr_kern__assert(struct sock_addr_kern *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __SOCK_ADDR_KERN_SKEL_H__ */
